pub struct WoaRenderFormat { /* private fields */ }Trait Implementations
Sourceimpl BinRead for WoaRenderFormat
impl BinRead for WoaRenderFormat
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for WoaRenderFormat
impl BinWrite for WoaRenderFormat
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for WoaRenderFormat
impl Clone for WoaRenderFormat
Sourcefn clone(&self) -> WoaRenderFormat
fn clone(&self) -> WoaRenderFormat
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WoaRenderFormat
Sourceimpl Debug for WoaRenderFormat
impl Debug for WoaRenderFormat
Sourceimpl<'de> Deserialize<'de> for WoaRenderFormat
impl<'de> Deserialize<'de> for WoaRenderFormat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WoaRenderFormat
Sourceimpl From<WoaRenderFormat> for RenderFormat
impl From<WoaRenderFormat> for RenderFormat
Sourcefn from(format: WoaRenderFormat) -> Self
fn from(format: WoaRenderFormat) -> Self
Converts to this type from the input type.
Sourceimpl Hash for WoaRenderFormat
impl Hash for WoaRenderFormat
Sourceimpl PartialEq for WoaRenderFormat
impl PartialEq for WoaRenderFormat
Sourceimpl PartialEq<RenderFormat> for WoaRenderFormat
impl PartialEq<RenderFormat> for WoaRenderFormat
Sourceimpl PartialEq<WoaRenderFormat> for RenderFormat
impl PartialEq<WoaRenderFormat> for RenderFormat
Sourceimpl RenderFormatMapping for WoaRenderFormat
impl RenderFormatMapping for WoaRenderFormat
const MAP: &'static [(u16, RenderFormat)]
fn try_from_u16(raw: u16) -> Option<RenderFormat>
fn try_to_u16(format: RenderFormat) -> Option<u16>
Sourceimpl Serialize for WoaRenderFormat
impl Serialize for WoaRenderFormat
impl StructuralPartialEq for WoaRenderFormat