pub struct TextureFlags { /* private fields */ }Implementations
Sourceimpl TextureFlags
Flags set in the texture files.
The “unstable” flags are not found in any production texture file. Use at your own risk
The other flags should not crash the game, but can also result in corrupted textures, use with caution
impl TextureFlags
Flags set in the texture files. The “unstable” flags are not found in any production texture file. Use at your own risk The other flags should not crash the game, but can also result in corrupted textures, use with caution
pub fn unknown4(&self) -> bool
pub fn deferred(&self) -> bool
pub fn unknown1(&self) -> bool
pub fn atlas(&self) -> bool
pub fn unknown3(&self) -> bool
👎Deprecated since 2.1.1:
No longer unknown, use lz4_compression
pub fn lz4_compression(&self) -> bool
pub fn set_deferred(&mut self, value: bool)
pub fn set_unknown1(&mut self, value: bool)
pub fn set_unknown3(&mut self, value: bool)
👎Deprecated since 2.1.1:
No longer unknown, use set_lz4_compression
pub fn set_lz4_compression(&mut self, value: bool)
pub fn set_atlas(&mut self, value: bool)
pub fn with_deferred(&self, value: bool) -> Self
pub fn with_unknown1(&mut self, value: bool) -> Self
pub fn with_atlas(&mut self, value: bool) -> Self
pub fn with_unknown3(&mut self, value: bool) -> Self
👎Deprecated since 2.1.1:
No longer unknown, use with_lz4_compression
pub fn with_lz4_compression(&mut self, value: bool) -> Self