Module texture_map
glacier_
texture
1.1.1
Module texture_
map
Module Items
Structs
Enums
In crate glacier_
texture
glacier_texture
Module
texture_
map
Structs

MipLevel
Texture
Map
Enums

Texture
Data
Represents the texture data, which can be either raw texture data or a mipblock read from a texd file.
Texture
MapError