pub enum TextureData {
Tex(Vec<u8>),
Mipblock1(MipblockData),
}Expand description
Represents the texture data, which can be either raw texture data or a mipblock read from a texd file.
Variants
Tex(Vec<u8>)
Raw texture data.
Mipblock1(MipblockData)
Mipblock data (obtained from a TEXD resource).